function [betahat, betavar, betastd]=ardlpmg(y,x)
% y is T x n matrix of observations on the dependent variable
% x is T x n x k matrix of observations on regressors
% it is allowed for NaNs (at the begining or end)
% ARDL(1,1) models are assumed

[T,n]=size(y);
k=size(x,3);
% estimation

sx=zeros(k,k); sy=zeros(k,1);
Tb=0;
for i=1:n
 xi=squeeze(x(:,i,:));
 yi=y(:,i);
 % find available sample (time periods with NaNs are dropped)
 ni=isnan([yi,xi]);
 omit=(sum(ni,2)>0);
 yi=yi(not(omit));
 xi=xi(not(omit),:);
 Ti=size(yi,1);
 %ARDL-PMG matrices
 Wi=[yi(2:Ti,1)-yi(1:Ti-1,1),xi(2:Ti,:)-xi(1:Ti-1,:), ones(Ti-1,1)]; 
 Hi=[yi(1:Ti-1,1),xi(2:Ti,:),xi(1:Ti-1,:), ones(Ti-1,1)]; %, ones(T-1,1)
 P=Hi*inv(Hi'*Hi)*Hi';
 M=P-P*Wi*inv(Wi'*P*Wi)*Wi'*P;

sx=sx+xi(2:Ti,:)'*M*xi(2:Ti,:);
sy=sy+xi(2:Ti,:)'*M*yi(2:Ti,1);
Tb=Tb+Ti/n;
end
betahat=inv(sx)*sy;


% now compute variance
sv=zeros(k,k);
for i=1:n
    xi=squeeze(x(:,i,:));
    yi=y(:,i);
    % find available sample (time periods with NaNs are dropped)
    ni=isnan([yi,xi]);
    omit=(sum(ni,2)>0);
    yi=yi(not(omit));
    xi=xi(not(omit),:);
    Ti=size(yi,1);
     
    Wi=[yi(2:Ti,1)-yi(1:Ti-1,1),xi(2:Ti,:)-xi(1:Ti-1,:), ones(Ti-1,1)]; 
    Hi=[yi(1:Ti-1,1),xi(2:Ti,:),xi(1:Ti-1,:), ones(Ti-1,1)]; %, ones(T-1,1)
    P=Hi*inv(Hi'*Hi)*Hi';
    M=P-P*Wi*inv(Wi'*P*Wi)*Wi'*P;
    
    vinm= (yi(2:Ti,1)-xi(2:Ti,:)*betahat);
    sv=sv+((xi(2:Ti,:)'*M*(vinm*vinm')*M*xi(2:Ti,:)));
end
OM=inv(sx)*sv*inv(sx);
betavar=OM;
betastd=diag(betavar).^0.5;
return